Learn R Programming

rsnps (version 0.1.6)

allgensnp: Get genotype data for all users at a particular snp.

Description

Get genotype data for all users at a particular snp.

Usage

allgensnp(snp = NA, df = FALSE, ...)

Arguments

snp
SNP name.
df
Return data.frame (TRUE) or not (FALSE) - default = FALSE.
...
Curl options passed on to GET.

Value

List of genotypes for all users at a certain SNP, or data.frame

Examples

Run this code
## Not run: 
# allgensnp(snp='rs7412')
# allgensnp('rs7412', df=TRUE)
# ## End(Not run)

Run the code above in your browser using DataLab