Learn R Programming

rsnps (version 0.1.6)

phenotypes_byid: Get all known variations and all users sharing that phenotype for one phenotype(-ID).

Description

Get all known variations and all users sharing that phenotype for one phenotype(-ID).

Usage

phenotypes_byid(phenotypeid = NA, return_ = c("description", "knownvars", "users"), ...)

Arguments

phenotypeid
ID of openSNP phenotype.
return_
Return data.frame (TRUE) or not (FALSE) - default = FALSE.
...
Curl options passed on to GET.

Value

List of description of phenotype, list of known variants, or data.frame of variants for each user with that phenotype.

Examples

Run this code
## Not run: 
# phenotypes_byid(phenotypeid=12, return_ = 'desc')
# phenotypes_byid(phenotypeid=12, return_ = 'knownvars')
# phenotypes_byid(phenotypeid=12, return_ = 'users')
# 
# # pass on curl options
# library("httr")
# phenotypes_byid(phenotypeid=12, return_ = 'desc', config=c(verbose(), timeout(1)))
# phenotypes_byid(phenotypeid=12, return_ = 'desc', config=verbose())
# ## End(Not run)

Run the code above in your browser using DataLab